# Introduction

## Description

### What is PyOWN?

PyOWN is a python library to build a OpenWebNet client to communicate to Bticino/Legrand home automation gateway.

### What is OpenWebNet?

OpenWebNet is a home automation protocol developed by Bticino (now part of Legrand) in the 2000s.
It is used to communicate to a gateway that is connected to the SCS bus where all the Bticino domotic devices are
connected.

### Why create a library for OpenWebNet?

The already existent libraries for python are either not maintained or not complete, so I decided to create a new one
that is easy to use and completely type annotated.

## Features

- Fully type annotated
- Asynchronous
- Easy to use

## Manuals

- Official OpenWebNet protocol documentation: [OpenWebNet protocol](https://developer.legrand.com/Documentation/)

## Disclaimer

- This library is not associated by any means with BTicino or Legrand companies
- The Open Web Net protocol is maintained and Copyright by BTicino/Legrand. The documentation of the protocol if freely
  accessible for developers on the Legrand developer web site
- "Open Web Net", "SCS", "MyHOME_Up", "MyHOME", "MyHOME_Play" and "Living Now" are registered trademarks by
  BTicino/Legrand
